==> haskell-data-default-instances-old-locale-0.0.1.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-old-locale.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-instances-old-locale
version:              0.0.1.1
visibility:           public
id:
    data-default-instances-old-locale-0.0.1.1-EYOTKCJAL5c3UZMjaDtYEc

key:
    data-default-instances-old-locale-0.0.1.1-EYOTKCJAL5c3UZMjaDtYEc

license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             Default instances for types in old-locale
category:             Data
abi:                  5eaec09b5f5d370102f9762643c5f084
exposed:              True
exposed-modules:      Data.Default.Instances.OldLocale
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-old-locale-0.0.1.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-old-locale-0.0.1.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-old-locale-0.0.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-instances-old-locale
hs-libraries:
    HSdata-default-instances-old-locale-0.0.1.1-EYOTKCJAL5c3UZMjaDtYEc

depends:
    base-4.17.2.1 data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-old-locale/html/data-default-instances-old-locale.haddock

haddock-html:
    /usr/share/doc/haskell-data-default-instances-old-locale/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-instances-old-locale-0.0.1.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-old-locale.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-instances-old-locale
version:              0.0.1.2
visibility:           public
id:
    data-default-instances-old-locale-0.0.1.2-JeoKu1Swtio1dSiHnVTVAw

key:
    data-default-instances-old-locale-0.0.1.2-JeoKu1Swtio1dSiHnVTVAw

license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             Default instances for types in old-locale
description:
    This module defines a '\''Default'\'' instance for the type '\''TimeLocale'\''.

category:             Data
abi:                  58ea3688789c5e3233148ec5aaa84f1c
exposed:              True
exposed-modules:      Data.Default.Instances.OldLocale
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-old-locale-0.0.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-old-locale-0.0.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-old-locale-0.0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-instances-old-locale
hs-libraries:
    HSdata-default-instances-old-locale-0.0.1.2-JeoKu1Swtio1dSiHnVTVAw

depends:
    base-4.17.2.1 data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-old-locale/html/data-default-instances-old-locale.haddock

haddock-html:
    /usr/share/doc/haskell-data-default-instances-old-locale/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
